@@ -23,7 +23,7 @@ class DatabaseType(str, Enum):
 
 
 class Settings(BaseSettings):
-    VERSION: str = "0.4.4"
+    VERSION: str = "0.4.5"
     API_VERSION: int = 1
     API_PRE_PATH: str = f"/api/v{API_VERSION}"
 
@@ -31,7 +31,7 @@ class Settings(BaseSettings):
     DEBUG: bool = False
     UNIT_TESTING: bool = False
 
-    SECRET_KEY: SecretBytes = os.urandom(32)
+    SECRET_KEY: SecretBytes = os.urandom(32)  # type:ignore
     BUILD_DATE: Optional[str] = None
     PROJECT_NAME: str = "FastAPI Backend"
     BACKEND_CORS_ORIGINS: Set[str] = set()
