@@ -177,9 +177,9 @@ class DocumentDBModel(CamelModel, abc.ABC):
 
     @classmethod
     async def create_indexes(cls) -> Optional[List[str]]:
-        if hasattr(cls, "Meta") and hasattr(cls.Meta, "indexes"):
+        if hasattr(cls, "Meta") and hasattr(cls.Meta, "indexes"):  # type:ignore
             db = get_db_client()
-            return await db.create_indexes(cls, cls.Meta.indexes)
+            return await db.create_indexes(cls, cls.Meta.indexes)  # type:ignore
         return None
 
     class Config:
@@ -208,7 +208,7 @@ class DocumentDBTimeStampedModel(DocumentDBModel):
         assert isinstance(mymodel.created, datetime)
     """
 
-    created: datetime
+    created: Optional[datetime] = None
 
     @validator("created", pre=True, always=True)
     def set_created_now(cls, v: datetime) -> datetime:
